==> quake-0.3.0.crate: quake-0.3.0/quake_webapp/README.md <==
# Quake Web

## Docs

Framework Spikes

- [ ] [Stencil Router](https://github.com/ionic-team/stencil-router)

Todo:

- [ ] Editor: https://github.com/KillerCodeMonkey/stencil-quill
  - [ ] Notion Like: [https://github.com/konstantinmuenster/notion-clone](https://github.com/konstantinmuenster/notion-clone)
  - [ ] [react-tapable-editor](https://github.com/ryuever/react-tapable-editor) with draft.js
- [x] SearchBox with Action
  - [x] Quake Action
- [x] Stencil.js Router
  - [x] [https://github.com/ionic-team/stencil-router](https://github.com/ionic-team/stencil-router)
  - [x] edit to  image editor view
- [x] Web Components Setup
  - [https://reactjs.org/docs/web-components.html](https://reactjs.org/docs/web-components.html)
  - [https://levelup.gitconnected.com/convert-existing-react-components-intowebcomponents-2b33b842ff9a](https://levelup.gitconnected.com/convert-existing-react-components-intowebcomponents-2b33b842ff9a) 
- [ ] Components 
  - [ ] Dashboard
  - [ ] ChartView
  - [ ] Ledge Render

## Chart

Compare: [https://medium.com/react-courses/react-charts-built-on-d3-what-should-you-pick-rechart-visx-niv-react-vi-or-victory-adc64406caa1](https://medium.com/react-courses/react-charts-built-on-d3-what-should-you-pick-rechart-visx-niv-react-vi-or-victory-adc64406caa1)

## Normal

https://github.com/uber/react-vis

https://recharts.org/en-US/api/SankeyChart


## Graph

https://airbnb.io/visx/linktypes

## Flow editor

link: [https://github.com/projectstorm/react-diagrams](https://github.com/projectstorm/react-diagrams) is  a super simple, no-nonsense diagramming library written in react that just works

screenshot:  [Example](https://github.com/projectstorm/react-diagrams/raw/master/.gitbook/assets/example1.jpg)

==> quake-0.4.0.crate: quake-0.4.0/quake_webapp/README.md <==
# Quake Web

## Docs

### Framework Spikes

#### Form.js

https://github.com/bpmn-io/form-js

#### Formio

GitHub: [https://github.com/formio](https://github.com/formio)

the type creator for entry type

- dragula

#### Others

- [ ] [Stencil Router](https://github.com/ionic-team/stencil-router)

Todo:

- [ ] Editor: https://github.com/KillerCodeMonkey/stencil-quill
  - [ ] Notion Like: [https://github.com/konstantinmuenster/notion-clone](https://github.com/konstantinmuenster/notion-clone)
  - [ ] [react-tapable-editor](https://github.com/ryuever/react-tapable-editor) with draft.js
- [x] SearchBox with Action
  - [x] Quake Action
- [x] Stencil.js Router
  - [x] [https://github.com/ionic-team/stencil-router](https://github.com/ionic-team/stencil-router)
  - [x] edit to  image editor view
- [x] Web Components Setup
  - [https://reactjs.org/docs/web-components.html](https://reactjs.org/docs/web-components.html)
  - [https://levelup.gitconnected.com/convert-existing-react-components-intowebcomponents-2b33b842ff9a](https://levelup.gitconnected.com/convert-existing-react-components-intowebcomponents-2b33b842ff9a) 
- [ ] Components 
  - [ ] Dashboard
  - [ ] ChartView
  - [ ] Ledge Render

## Chart

Compare: [https://medium.com/react-courses/react-charts-built-on-d3-what-should-you-pick-rechart-visx-niv-react-vi-or-victory-adc64406caa1](https://medium.com/react-courses/react-charts-built-on-d3-what-should-you-pick-rechart-visx-niv-react-vi-or-victory-adc64406caa1)

## Normal

https://github.com/uber/react-vis

https://recharts.org/en-US/api/SankeyChart


## Graph

https://airbnb.io/visx/linktypes

## Flow editor

link: [https://github.com/projectstorm/react-diagrams](https://github.com/projectstorm/react-diagrams) is  a super simple, no-nonsense diagramming library written in react that just works

screenshot:  [Example](https://github.com/projectstorm/react-diagrams/raw/master/.gitbook/assets/example1.jpg)
